@@ -478,7 +478,7 @@ EOT
 
                 if ($showLatest && $showVersion) {
                     foreach ($packages[$type] as $package) {
-                        if (is_object($package)) {
+                        if (is_object($package) && !Preg::isMatch($ignoredPackagesRegex, $package->getPrettyName())) {
                             $latestPackage = $this->findLatestPackage($package, $composer, $platformRepo, $showMajorOnly, $showMinorOnly, $showPatchOnly, $platformReqFilter);
                             if ($latestPackage === null) {
                                 continue;
@@ -535,10 +535,13 @@ EOT
                             $packageViewData['homepage'] = $package instanceof CompletePackageInterface ? $package->getHomepage() : null;
                             $packageViewData['source'] = PackageInfo::getViewSourceUrl($package);
                         }
-                        $nameLength = max($nameLength, strlen($package->getPrettyName()));
+                        $nameLength = max($nameLength, strlen($packageViewData['name']));
                         if ($writeVersion) {
                             $packageViewData['version'] = $package->getFullPrettyVersion();
-                            $versionLength = max($versionLength, strlen($package->getFullPrettyVersion()));
+                            if ($format === 'text') {
+                                $packageViewData['version'] = ltrim($packageViewData['version'], 'v');
+                            }
+                            $versionLength = max($versionLength, strlen($packageViewData['version']));
                         }
                         if ($writeReleaseDate) {
                             if ($package->getReleaseDate() !== null) {
@@ -553,6 +556,9 @@ EOT
                         }
                         if ($writeLatest && $latestPackage) {
                             $packageViewData['latest'] = $latestPackage->getFullPrettyVersion();
+                            if ($format === 'text') {
+                                $packageViewData['latest'] = ltrim($packageViewData['latest'], 'v');
+                            }
                             $packageViewData['latest-status'] = $this->getUpdateStatus($latestPackage, $package);
                             $latestLength = max($latestLength, strlen($packageViewData['latest']));
                         } elseif ($writeLatest) {
