@@ -53,7 +53,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewest(): void
@@ -69,7 +69,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewestPicksLatest(): void
@@ -85,7 +85,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewestPicksLatestStableWithPreferStable(): void
@@ -102,7 +102,7 @@ class DefaultPolicyTest extends TestCase
         $policy = new DefaultPolicy(true);
         $selected = $policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewestWithDevPicksNonDev(): void
@@ -118,7 +118,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewestWithPreferredVersionPicksPreferredVersionIfAvailable(): void
@@ -137,7 +137,7 @@ class DefaultPolicyTest extends TestCase
         $policy = new DefaultPolicy(false, false, ['a' => '1.1.0.0']);
         $selected = $policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewestWithPreferredVersionPicksNewestOtherwise(): void
@@ -154,7 +154,7 @@ class DefaultPolicyTest extends TestCase
         $policy = new DefaultPolicy(false, false, ['a' => '1.1.0.0']);
         $selected = $policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectNewestWithPreferredVersionPicksLowestIfPreferLowest(): void
@@ -171,7 +171,7 @@ class DefaultPolicyTest extends TestCase
         $policy = new DefaultPolicy(false, true, ['a' => '1.1.0.0']);
         $selected = $policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testRepositoryOrderingAffectsPriority(): void
@@ -193,7 +193,7 @@ class DefaultPolicyTest extends TestCase
         $expected = [$package2->getId()];
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
 
         $this->repositorySet = new RepositorySet('dev');
         $this->repositorySet->addRepository($repo2);
@@ -204,7 +204,7 @@ class DefaultPolicyTest extends TestCase
         $expected = [$package4->getId()];
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectLocalReposFirst(): void
@@ -235,7 +235,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectAllProviders(): void
@@ -255,7 +255,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testPreferNonReplacingFromSameRepo(): void
@@ -274,7 +274,7 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testPreferReplacingPackageFromSameVendor(): void
@@ -294,7 +294,7 @@ class DefaultPolicyTest extends TestCase
         $expected = $literals;
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals, 'vendor-a/package');
-        $this->assertEquals($expected, $selected);
+        self::assertEquals($expected, $selected);
 
         // test with reversed order in repo
         $repo = new ArrayRepository;
@@ -310,7 +310,7 @@ class DefaultPolicyTest extends TestCase
         $expected = $literals;
 
         $selected = $this->policy->selectPreferredPackages($pool, $literals, 'vendor-a/package');
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 
     public function testSelectLowest(): void
@@ -328,6 +328,6 @@ class DefaultPolicyTest extends TestCase
 
         $selected = $policy->selectPreferredPackages($pool, $literals);
 
-        $this->assertSame($expected, $selected);
+        self::assertSame($expected, $selected);
     }
 }
