@@ -162,6 +162,6 @@ class FossilDownloaderTest extends TestCase
     {
         $downloader = $this->getDownloaderMock(null);
 
-        $this->assertEquals('source', $downloader->getInstallationSource());
+        self::assertEquals('source', $downloader->getInstallationSource());
     }
 }
