@@ -138,20 +138,20 @@ class InstallerTest extends TestCase
         $result = $installer->run();
 
         $output = str_replace("\r", '', $io->getOutput());
-        $this->assertEquals(0, $result, $output);
+        self::assertEquals(0, $result, $output);
 
         $expectedInstalled = $options['install'] ?? [];
         $expectedUpdated = $options['update'] ?? [];
         $expectedUninstalled = $options['uninstall'] ?? [];
 
         $installed = $installationManager->getInstalledPackages();
-        $this->assertEquals($this->makePackagesComparable($expectedInstalled), $this->makePackagesComparable($installed));
+        self::assertEquals($this->makePackagesComparable($expectedInstalled), $this->makePackagesComparable($installed));
 
         $updated = $installationManager->getUpdatedPackages();
-        $this->assertSame($expectedUpdated, $updated);
+        self::assertSame($expectedUpdated, $updated);
 
         $uninstalled = $installationManager->getUninstalledPackages();
-        $this->assertSame($expectedUninstalled, $uninstalled);
+        self::assertSame($expectedUninstalled, $uninstalled);
     }
 
     /**
@@ -279,7 +279,7 @@ class InstallerTest extends TestCase
     {
         if ($condition) {
             eval('$res = '.$condition.';');
-            if (!$res) { // @phpstan-ignore-line
+            if (!$res) { // @phpstan-ignore variable.undefined
                 $this->markTestSkipped($condition);
             }
         }
@@ -441,10 +441,10 @@ class InstallerTest extends TestCase
         }
 
         $output = str_replace("\r", '', $io->getOutput());
-        $this->assertEquals($expectResult, $result, $output . stream_get_contents($appOutput));
+        self::assertEquals($expectResult, $result, $output . stream_get_contents($appOutput));
         if ($expectLock && isset($actualLock)) {
             unset($actualLock['hash'], $actualLock['content-hash'], $actualLock['_readme'], $actualLock['plugin-api-version']);
-            $this->assertEquals($expectLock, $actualLock);
+            self::assertEquals($expectLock, $actualLock);
         }
 
         if ($expectInstalled !== null) {
@@ -461,18 +461,18 @@ class InstallerTest extends TestCase
                 return strcmp($a['name'], $b['name']);
             });
 
-            $this->assertSame($expectInstalled, $actualInstalled);
+            self::assertSame($expectInstalled, $actualInstalled);
         }
 
         /** @var InstallationManagerMock $installationManager */
         $installationManager = $composer->getInstallationManager();
-        $this->assertSame(rtrim($expect), implode("\n", $installationManager->getTrace()));
+        self::assertSame(rtrim($expect), implode("\n", $installationManager->getTrace()));
 
         if ($expectOutput) {
             $output = Preg::replace('{^    - .*?\.ini$}m', '__inilist__', $output);
             $output = Preg::replace('{(__inilist__\r?\n)+}', "__inilist__\n", $output);
 
-            $this->assertStringMatchesFormat(rtrim($expectOutput), rtrim($output));
+            self::assertStringMatchesFormat(rtrim($expectOutput), rtrim($output));
         }
     }
 
